@@ -1,5 +1,5 @@
 test_that("`bluebrown_colors()` works", {
-  expect_equal(
+  expect_identical(
     as.vector(bluebrown_colors("blue", "brown")),
     c("#5B93AE", "#61381A")
   )
@@ -7,7 +7,7 @@ test_that("`bluebrown_colors()` works", {
 
 
 test_that("`material_colors()` works", {
-  expect_equal(
+  expect_identical(
     as.vector(material_colors("indigo", "lime")),
     c("#3F51B5", "#CDDC39")
   )
@@ -22,9 +22,9 @@ test_that("`social_colors()` works", {
 })
 
 test_that("`see_colors()` works", {
-  expect_equal(as.vector(see_colors("indigo", "lime")), c("#303960", "#f7fbe1"))
+  expect_identical(as.vector(see_colors("indigo", "lime")), c("#303960", "#f7fbe1"))
 })
 
 test_that("`flat_colors()` works", {
-  expect_equal(as.vector(flat_colors("dark red", "teal")), c("#c0392b", "#16a085"))
+  expect_identical(as.vector(flat_colors("dark red", "teal")), c("#c0392b", "#16a085"))
 })
