@@ -1,8 +1,4 @@
 test_that("scale_color_ functions work correctly", {
-  skip_if_not_or_load_if_installed("vdiffr")
-  skip_if_not_or_load_if_installed("ggplot2")
-
-
   vdiffr::expect_doppelganger(
     title = "scale_color_bluebrown_d() works",
     fig = ggplot(iris, aes(x = Species, y = Sepal.Length, fill = Species)) +
